#!/bin/bash
#
# make a product stub for Apple clang

usage()
{
   echo "USAGE: `basename ${0}` <product_dir> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`

    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
maketar=${2}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=apple_clang
origpkgver=v1_00_00
pkgver=${origpkgver}
ssibuildshims_version=v0_15_02
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`

get_this_dir

get_ssibuildshims

source define_basics NO_QUAL

if [ ${OS1} = "Darwin" ]
then
  echo "this product stub is only supported for Darwin"
else
  echo "this product stub is not supported for ${OS1}"
  exit 1
fi


echo "building ${package} for ${OS}-${plat} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${pkgdir}
if [ ! -d ${pkgdir} ]
then
   echo "ERROR: failed to create ${pkgdir}"
   exit 1
fi

mkdir -p ${pkgdir}/bin
if [ ! -d ${pkgdir}/bin ]
then
   echo "ERROR: failed to create ${pkgdir}/bin"
   exit 1
fi

cd ${pkgdir}/bin

if [ -e /usr/bin/clang++ ]; then
ln -s /usr/bin/clang++
fi
if [ -e /usr/bin/clang ]; then
ln -s /usr/bin/clang
fi
if [ -e /usr/bin/c++ ]; then
ln -s /usr/bin/c++
fi
if [ -e /usr/bin/g++ ]; then
ln -s /usr/bin/g++
fi
if [ -e /usr/bin/gcc ]; then
ln -s /usr/bin/gcc
fi
if [ -e /usr/bin/gcov ]; then
ln -s /usr/bin/gcov
fi
if [ -e /usr/local/bin/gfortran ]; then
ln -s /usr/local/bin/gfortran
fi
if [ -e /usr/bin/install ]; then
ln -s /usr/bin/install
fi

if [ ! -e ${pkgdir}/bin/clang ]
then
   echo "ERROR: failed to create ${pkgdir}/bin/clang"
   echo "       Something is very wrong"
   exit 1
fi

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} NO_QUAL CURRENT

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -z ${product_dir}:${PRODUCTS}
echo "${package} is installed at ${APPLE_CLANG_FQ_DIR}"


# this must be last because it will exit
if [ "${maketar}" = "tar" ]
then
    ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL CURRENT
fi

exit 0
